/*
   Sequential search for "aardvark" in each file in the current directory.

   This version does file I/O using a BufferedReader wrapped around
   a FileReader.
*/

import java.time.Instant;
import java.time.Duration;
import java.util.Date;
import java.text.SimpleDateFormat;
import java.io.IOException;
import java.io.FileReader;
import java.io.BufferedReader;
import java.nio.file.Files;
import java.nio.file.Paths;
import java.nio.file.Path;

public class SearchSequential_v3_Files
{
   private static final int BUFFERSIZE = 16 * 8192; // changing this doesn't seem to matter
   private static int totalLines = 0;
   private static final SimpleDateFormat ft = new SimpleDateFormat("hh:mm:ss");

   public static void main(String[] args) throws IOException
   {
      System.out.println(ft.format(new Date()) + " Search Sequential ver 3 in all Files");
      Instant start = Instant.now();

      Files.list(Paths.get("."))
             .filter(p -> p.toString().endsWith(".txt"))
               .forEach(p -> searchInFile(p));

      Instant stop = Instant.now();
      long time = Duration.between(start, stop).toMillis();
      System.out.printf("%s processed %,d lines from all files.\n",
                       ft.format(new Date()), totalLines);
      System.out.printf("elapsed time: %,dms\n", time);
   }


   public static void searchInFile(Path path)
   {
      int lineNumber = 0;

      try
      {
         final String fileName = path.getFileName().toString();
         final BufferedReader br = new BufferedReader(new FileReader(fileName), BUFFERSIZE);

         String oneLine = null;
         while ( (oneLine = br.readLine()) != null )
         {
            ++lineNumber;
            for (int i = 0; i < oneLine.length() - 8; ++i)
            {
               if ( 'a' == oneLine.charAt(i)
                 && 'a' == oneLine.charAt(i+1)
                 && 'r' == oneLine.charAt(i+2)
                 && 'd' == oneLine.charAt(i+3)
                 && 'v' == oneLine.charAt(i+4)
                 && 'a' == oneLine.charAt(i+5)
                 && 'r' == oneLine.charAt(i+6)
                 && 'k' == oneLine.charAt(i+7) )
               {
                  System.out.printf("%s line %,d in %s (total line no %,d).\n",
                                     ft.format(new Date()),
                                     lineNumber,
                                     fileName,
                                     lineNumber + totalLines);
               }
            }
         }
         br.close();
         totalLines += lineNumber;
      }
      catch(IOException e){throw new Error(e);}
   }
}
